@@ -142,6 +142,11 @@ def es_condition_by_terms(bool_must_list, column, param_list, is_need_decrypt_or
                 }})
 
 
+def es_condition_by_wildcard(bool_list, column, param):
+    if param:
+        bool_list.append({"wildcard": {column: f"*{param}*"}})
+
+
 def es_condition_by_exist(bool_must_list, param, is_exists="是"):
     if param:
         if is_exists == "是" or is_exists == "true" or is_exists == True:
