@@ -179,3 +179,57 @@ def list2table(title: str, head, data: list, column_keys: dict = None, index_dic
             ix += 1
 
     return result
+
+
+def list2table_with_page(title: str, head, data: list, column_keys: dict = None, index_dict: dict = None,
+                         page_num: int = 1, page_size: int = 10, total: int = 0):
+    """
+    list数据转换成表格
+    :param total: 数据总数
+    :param page_size: 每页数量
+    :param page_num: 页码
+    :param index_dict: 索引列信息，实例：{"start":1,"column_name":"序号"，"index"："index"，"key"："index"}
+    :param column_keys:数据对应点的keys，实例1：{"name1":"name2"} 说明：name1：接口返回字段名，name2:是数据的key,支持多层key，通过.连接，例如：basic.name
+    :param data: es返回的数据
+    :param title: 表格标题，字符串类型
+    :param head: 表头，支持dict和list ，实例1：{"企业名称": "name"},实例2：[{"企业名称": "name"}]
+
+    """
+
+    result = {
+        "title": title,
+        "columns": [],
+        "dataSource": [],
+        "total": 0
+    }
+    if isinstance(head, dict):
+        for key, value in head.items():
+            result["columns"].append({"title": key,
+                                      "dataIndex": value, "key": value})
+    elif isinstance(head, list):
+        result["columns"] = head
+    else:
+        raise Exception(f'head={head} is error')
+    if column_keys:
+        for item in data:
+            data_item = {
+            }
+            for key, value in column_keys.items():
+                data_item[key] = get_value_from_dict(item, value)
+            result["dataSource"].append(data_item)
+    else:
+        result["dataSource"] = data
+    result["total"] = total
+
+    if index_dict:
+        ix = index_dict.get("start", 1) + (page_num - 1) * page_size
+        index_title = index_dict.get("column_name", "序号")
+        data_index = index_dict.get("index", "index")
+        data_key = index_dict.get("key", "index")
+        result["columns"].append({"title": index_title,
+                                  "dataIndex": data_index, "key": data_key})
+        for item in result["dataSource"]:
+            item[data_key] = ix
+            ix += 1
+
+    return result
